called by readHMDweb() to find file urls. This assumes that CNTRY is actually available in the HFD.
getHMDitemavail(CNTRY)a tibble of all available data items for the selected country. There are several useful identifiers that can help determine the appropriate file, including the `measure`, `lexis`, `sex` and interval information, as detected from the item names.
character. HMD country short code.